//============================================================================================================
//	$Id$
//
//	$Author$
//
//	$DateTime$
//============================================================================================================

#ifndef _LFC1_FILESYSTEM_CDIRECTORY_HPP_
#define _LFC1_FILESYSTEM_CDIRECTORY_HPP_

#include <vector>
#include <boost/filesystem.hpp>

#include "lfc1/filesystem/filesystemexp.hpp"

namespace lfc1 { namespace filesystem {

///	@ingroup LFC1_FILESYSTEM
///	@headerfile lfc1/filesystem/cdirectory.hpp
///	@brief This class wraps a directory iterator so that directory entries could be loaded and sorted.
///
class LFC1_FILESYSTEM_API CDirectory
{
public:
	// Type definitions
	typedef boost::filesystem::directory_entry TEntry;	///< The type of a directory entry.
	typedef std::vector<TEntry> TEntries;	///< The type of the directory entries container.
	typedef TEntries::const_iterator TIterator;	///< The type of the directory entries container iterator.

	// Constructors/destructor
	CDirectory(const boost::filesystem::path& arPath);
	CDirectory(const CDirectory& arRHS);
	CDirectory(CDirectory&& arRHS);
	~CDirectory() noexcept;

	// Assignment
	CDirectory& operator=(const CDirectory& arRHS);
	CDirectory& operator=(CDirectory&& arRHS) noexcept;

	// Instance setters/getters
	boost::filesystem::path mvGetPath() const;
	unsigned mvGetNumEntries() const noexcept;
	TIterator begin() const noexcept;
	TIterator end() const noexcept;

	// Instance special operations
	void swap(CDirectory& arRHS) noexcept;
	void mvRefresh();

private:
	// Instance data
	boost::filesystem::path mvPath;
	TEntries mvEntries;
};

LFC1_FILESYSTEM_API void swap(CDirectory& arLHS, CDirectory& arRHS) noexcept;

} /* namespace filesystem */ } /* namespace lfc1 */

#endif // _LFC1_FILESYSTEM_CDIRECTORY_HPP_

//============================================================================================================
//	End of Code
//============================================================================================================
