//============================================================================================================
//	$Id$
//
//	$Author$
//
//	$DateTime$
//============================================================================================================

#ifndef _LFC1_FILESYSTEM_CRECDIRECTORY_HPP_
#define _LFC1_FILESYSTEM_CRECDIRECTORY_HPP_

#include <vector>
#include <boost/filesystem.hpp>

#include "lfc1/filesystem/filesystemexp.hpp"

namespace lfc1 { namespace filesystem {

///	@ingroup LFC1_FILESYSTEM
///	@headerfile lfc1/filesystem/crecdirectory.hpp
///	@brief This class wraps a recursive directory iterator so that directory entries could be loaded and
///		   sorted.
///
class LFC1_FILESYSTEM_API CRecDirectory
{
public:
	// Type definitions
	typedef std::pair<boost::filesystem::directory_entry, int> TEntry;	///< The type of a directory entry.
	typedef std::vector<TEntry> TEntries;	///< The type of the directory entries container.
	typedef TEntries::const_iterator TIterator;	///< The type of the directory entries container iterator.

	// Constructors/destructor
	CRecDirectory(const boost::filesystem::path& arPath);
	CRecDirectory(const CRecDirectory& arRHS);
	CRecDirectory(CRecDirectory&& arRHS);
	~CRecDirectory() noexcept;

	// Assignment
	CRecDirectory& operator=(const CRecDirectory& arRHS);
	CRecDirectory& operator=(CRecDirectory&& arRHS) noexcept;

	// Instance setters/getters
	int mvGetLevelCount() const noexcept;
	boost::filesystem::path mvGetPath() const;
	unsigned mvGetNumEntries() const noexcept;
	TIterator begin() const noexcept;
	TIterator end() const noexcept;

	// Instance special operations
	void swap(CRecDirectory& arRHS) noexcept;
	void mvRefresh();

private:
	// Instance data
	int mvLevelCount;
	boost::filesystem::path mvPath;
	TEntries mvEntries;
};

LFC1_FILESYSTEM_API void swap(CRecDirectory& arLHS, CRecDirectory& arRHS) noexcept;

} /* namespace filesystem */ } /* namespace lfc1 */

#endif // _LFC1_FILESYSTEM_CRECDIRECTORY_HPP_

//============================================================================================================
//	End of Code
//============================================================================================================
