//============================================================================================================
//	$Id$
//
//	$Author$
//
//	$DateTime$
//============================================================================================================

#ifndef _LFC1_MISC_CDEMANGLER_HPP_
#define _LFC1_MISC_CDEMANGLER_HPP_

#include "lfc1/misc/miscexp.hpp"

namespace lfc1 { namespace misc {

///	@ingroup LFC1_MISC
///	@headerfile lfc1/misc/cdemangler.hpp
///	@brief This class provides RAII to name demangling.
///
///	Some platforms require name demangling while other platforms do not.  This class is aware which platforms
///	require name demangling and does nothing for those platforms that do not require name demangling.
///
class LFC1_MISC_API CDemangler
{
public:
	// Constructors/destructor
	explicit CDemangler(const char* apTypeName) noexcept;
	CDemangler(const CDemangler&) = delete;	///< Not supported.
	CDemangler(CDemangler&&) = delete;	///< Not supported.
	~CDemangler() noexcept;

	// Assignment
	CDemangler& operator=(const CDemangler&) = delete;	///< Not supported.
	CDemangler& operator=(CDemangler&&) = delete;	///< Not supported.

	// Conversions
	operator const char* () const noexcept;

private:
	// Instance data
	const char* mpTypeName;
//#if defined(__LINUX__) || defined(__HPUXI__)
#if defined(__LINUX__)
	char* mpDemangledTypeName;
#endif
};

} /* namespace misc */ } /* namespace lfc1 */

#endif // _LFC1_MISC_CDEMANGLER_HPP_

//============================================================================================================
//	End of Code
//============================================================================================================
