//============================================================================================================
//	$Id$
//
//	$Author$
//
//	$DateTime$
//============================================================================================================

#ifndef _LFC1_NUMERIC_ENDIANTYPES_HPP_
#define _LFC1_NUMERIC_ENDIANTYPES_HPP_

#include <cstdint>

#include "lfc1/numeric/cinteger.hpp"

namespace lfc1 { namespace numeric {

///	@ingroup LFC1_NUMERIC
///	@headerfile lfc1/numeric/endiantypes.hpp
///	@brief This type represents a 16-bit little endian signed integer.
///
#if defined(__L_ENDIAN__)
typedef std::int16_t TInt16LE;
#endif
#if defined(__B_ENDIAN__)
typedef CInteger<std::int16_t> TInt16LE;
#endif

///	@ingroup LFC1_NUMERIC
///	@headerfile lfc1/numeric/endiantypes.hpp
///	@brief This type represents a 16-bit big endian signed integer.
///
#if defined(__L_ENDIAN__)
typedef CInteger<std::int16_t> TInt16BE;
#endif
#if defined(__B_ENDIAN__)
typedef std::int16_t TInt16BE;
#endif

///	@ingroup LFC1_NUMERIC
///	@headerfile lfc1/numeric/endiantypes.hpp
///	@brief This type represents a 16-bit little endian unsigned integer.
///
#if defined(__L_ENDIAN__)
typedef std::uint16_t TUInt16LE;
#endif
#if defined(__B_ENDIAN__)
typedef CInteger<std::uint16_t> TUInt16LE;
#endif

///	@ingroup LFC1_NUMERIC
///	@headerfile lfc1/numeric/endiantypes.hpp
///	@brief This type represents a 16-bit big endian unsigned integer.
///
#if defined(__L_ENDIAN__)
typedef CInteger<std::uint16_t> TUInt16BE;
#endif
#if defined(__B_ENDIAN__)
typedef std::uint16_t TUInt16BE;
#endif

///	@ingroup LFC1_NUMERIC
///	@headerfile lfc1/numeric/endiantypes.hpp
///	@brief This type represents a 32-bit little endian signed integer.
///
#if defined(__L_ENDIAN__)
typedef std::int32_t TInt32LE;
#endif
#if defined(__B_ENDIAN__)
typedef CInteger<std::int32_t> TInt32LE;
#endif

///	@ingroup LFC1_NUMERIC
///	@headerfile lfc1/numeric/endiantypes.hpp
///	@brief This type represents a 32-bit big endian signed integer.
///
#if defined(__L_ENDIAN__)
typedef CInteger<std::int32_t> TInt32BE;
#endif
#if defined(__B_ENDIAN__)
typedef std::int32_t TInt32BE;
#endif

///	@ingroup LFC1_NUMERIC
///	@headerfile lfc1/numeric/endiantypes.hpp
///	@brief This type represents a 32-bit little endian unsigned integer.
///
#if defined(__L_ENDIAN__)
typedef std::uint32_t TUInt32LE;
#endif
#if defined(__B_ENDIAN__)
typedef CInteger<std::uint32_t> TUInt32LE;
#endif

///	@ingroup LFC1_NUMERIC
///	@headerfile lfc1/numeric/endiantypes.hpp
///	@brief This type represents a 32-bit big endian unsigned integer.
///
#if defined(__L_ENDIAN__)
typedef CInteger<std::uint32_t> TUInt32BE;
#endif
#if defined(__B_ENDIAN__)
typedef std::uint32_t TUInt32BE;
#endif

///	@ingroup LFC1_NUMERIC
///	@headerfile lfc1/numeric/endiantypes.hpp
///	@brief This type represents a 64-bit little endian signed integer.
///
#if defined(__L_ENDIAN__)
typedef std::int64_t TInt64LE;
#endif
#if defined(__B_ENDIAN__)
typedef CInteger<std::int64_t> TInt64LE;
#endif

///	@ingroup LFC1_NUMERIC
///	@headerfile lfc1/numeric/endiantypes.hpp
///	@brief This type represents a 64-bit big endian signed integer.
///
#if defined(__L_ENDIAN__)
typedef CInteger<std::int64_t> TInt64BE;
#endif
#if defined(__B_ENDIAN__)
typedef std::int64_t TInt64BE;
#endif

///	@ingroup LFC1_NUMERIC
///	@headerfile lfc1/numeric/endiantypes.hpp
///	@brief This type represents a 64-bit little endian unsigned integer.
///
#if defined(__L_ENDIAN__)
typedef std::uint64_t TUInt64LE;
#endif
#if defined(__B_ENDIAN__)
typedef CInteger<std::uint64_t> TUInt64LE;
#endif

///	@ingroup LFC1_NUMERIC
///	@headerfile lfc1/numeric/endiantypes.hpp
///	@brief This type represents a 64-bit big endian unsigned integer.
///
#if defined(__L_ENDIAN__)
typedef CInteger<std::uint64_t> TUInt64BE;
#endif
#if defined(__B_ENDIAN__)
typedef std::uint64_t TUInt64BE;
#endif

} /* namespace numeric */ } /* namespace lfc1 */

#endif // _LFC1_NUMERIC_ENDIANTYPES_HPP_

//============================================================================================================
//	End of Code
//============================================================================================================
