//============================================================================================================
//	$Id$
//
//	$Author$
//
//	$DateTime$
//============================================================================================================

#ifndef _LFC1_SYSTEM_ERROR_CATEGORY_HPP_
#define _LFC1_SYSTEM_ERROR_CATEGORY_HPP_

#include <string>
#include <system_error>
#include <memory>
#include <mutex>

#include "lfc1/system/systemexp.hpp"

namespace lfc1 { namespace system {

///	@ingroup LFC1_SYSTEM
///	@headerfile lfc1/system/cerrorcategory.hpp
///	@brief This enumeration defines the error codes for this library.
///
enum ErrC
{
	E_EC_SUCCESS,
	E_EC_DIR_OPEN_ERROR,
	E_EC_DIR_READ_ERROR,
	E_EC_DUP_NAMEVALUE,
	E_EC_MISSING_NAMEVALUE,
	E_EC_INVALID_NAMEVALUE,
	E_EC_MISSING_LANGUAGE_PART,
	E_EC_MISSING_CURRENCY_PART,
	E_EC_MISSING_COUNTRY_PART,
	E_EC_READ_PAST_EOF,
	E_EC_INVALID_TEXT_ENCODING,
	E_EC_MISSING_UTF16_BOM,
	E_EC_NO_FRAMES,
	E_EC_READ_PAST_EOT,
	E_EC_CHECKSUM_MISMATCH
};

///	@ingroup LFC1_SYSTEM
///	@headerfile lfc1/system/cerrorcategory.hpp
///	@brief This class is an error category for this library.
///
///	@note This class uses the Singleton design pattern thus only one instance of this class exists within the
///		  same process.
///
class LFC1_SYSTEM_API CErrorCategory : std::error_category
{
public:
	// Class special operations
	static std::error_category& smrGetErrorCategory() noexcept;

	// Constructors/destructor
	CErrorCategory(const CErrorCategory&) = delete;	///< Not supported.
	CErrorCategory(CErrorCategory&&) = delete;	///< Not supported.
	virtual ~CErrorCategory() noexcept;

	// Assignment
	CErrorCategory& operator=(const CErrorCategory&) = delete;	///< Not supported.
	CErrorCategory& operator=(CErrorCategory&&) = delete;	///< Not supported.

	// Interface implementation
	virtual const char* name() const noexcept;
	virtual std::string message(int ev) const;

protected:
	// Constructors/destructor
	CErrorCategory() noexcept;

private:
	// Type definitions
	typedef std::unique_ptr<CErrorCategory> TPointer;

	// Class special operations
	static void smvSetErrorCategory();

	// Class data
	static TPointer smpErrorCategory;
	static std::once_flag smvFlag;
};

LFC1_SYSTEM_API std::error_category& grCategory() noexcept;

} /* namespace system */ } /* namespace lfc1 */

#endif // _LFC1_SYSTEM_ERROR_CATEGORY_HPP_

//============================================================================================================
//	End of Code
//============================================================================================================
