//============================================================================================================
//	$Id$
//
//	$Author$
//
//	$DateTime$
//============================================================================================================

#include "lfc1/system/cerrorcategory.hpp"

using namespace std;

namespace lfc1 { namespace system {

///	@brief This function obtains a reference to a single error category object.
///
///	@return A reference to a single error category object.
///
std::error_category& CErrorCategory::smrGetErrorCategory() noexcept
{
	call_once(smvFlag, smvSetErrorCategory);
	return *smpErrorCategory;
}

///	@brief This function creates a default CErrorCategory object.
///
CErrorCategory::CErrorCategory() noexcept
{
}

///	@brief This function destroys a CErrorCategory object.
///
CErrorCategory::~CErrorCategory() noexcept
{
}

///	@brief This function obtains the name of the error category.
///
///	@return The name of the error category.
///
const char* CErrorCategory::name() const noexcept
{
	return "lfc1";
}

/// @brief This function obtains the message equivalent to the given error code.
///
///	@param[in]	ev	The error code.
///
///	@return The message equivalent to the given error code.
///
std::string CErrorCategory::message(int ev) const
{
	static const char* vMessages[] =
	{
		"Success",
		"Directory open error",
		"Directory read error",
		"Duplicate name for name/value pair",
		"Missing name/value pair",
		"Invalid name/value pair",
		"Missing part in language data",
		"Missing part in currency data",
		"Missing part in country data",
		"Read past end-of-file",
		"Invalid text encoding",
		"Missing UTF-16 BOM",
		"The ID3 tag has no frames",
		"Read past end-of-tag",
		"Checksum mismatch"
	};

	return vMessages[ev];
}

///	@brief This function creates the single instance of the CErrorCategory object.
///
///	@exception	std::bad_alloc	Indicates a memory allocation failure.
///
void CErrorCategory::smvSetErrorCategory()
{
	TPointer pErrorCategory(new CErrorCategory);
	using std::swap;
	swap(smpErrorCategory, pErrorCategory);
}

CErrorCategory::TPointer CErrorCategory::smpErrorCategory;
std::once_flag CErrorCategory::smvFlag;

///	@ingroup LFC1_SYSTEM
///	@headerfile lfc1/system/cerrorcategory.hpp
///	@brief This function obtains a reference to the single error category object.
///
///	@return	A reference to the single error category object.
///
std::error_category& grCategory() noexcept
{
	return CErrorCategory::smrGetErrorCategory();
}

} /* namespace system */ } /* namespace lfc1 */

//============================================================================================================
//	End of Code
//============================================================================================================
